==> okteta_0.25.4.orig.tar.xz: okteta-0.25.4/kasten/controllers/view/poddecoder/poddecodertoolviewfactory.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "poddecodertoolviewfactory.h"

// lib
#include "poddecodertoolview.h"
#include "poddecodertool.h"
// KF5
#include <KLocalizedString>

namespace Kasten {

PodDecoderToolViewFactory::PodDecoderToolViewFactory() = default;

PodDecoderToolViewFactory::~PodDecoderToolViewFactory() = default;

QString PodDecoderToolViewFactory::iconName() const { return QStringLiteral("okteta"); }
QString PodDecoderToolViewFactory::title()       const { return i18nc("@title:window", "Decoding Table"); }
QString PodDecoderToolViewFactory::id()       const { return QStringLiteral("org.kde.okteta.PodDecoderToolView"); }
SidePosition PodDecoderToolViewFactory::defaultPosition() const { return RightSidePosition; }

AbstractToolView* PodDecoderToolViewFactory::create(AbstractTool* tool)
{
    return new PODDecoderToolView(qobject_cast<PODDecoderTool*>(tool));
}

}

==> okteta-0.26.2.tar.xz: okteta-0.26.2/kasten/controllers/view/poddecoder/poddecodertoolviewfactory.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2010 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "poddecodertoolviewfactory.hpp"

// lib
#include "poddecodertoolview.hpp"
#include "poddecodertool.hpp"
// KF
#include <KLocalizedString>

namespace Kasten {

PodDecoderToolViewFactory::PodDecoderToolViewFactory() = default;

PodDecoderToolViewFactory::~PodDecoderToolViewFactory() = default;

QString PodDecoderToolViewFactory::iconName() const { return QStringLiteral("okteta"); }
QString PodDecoderToolViewFactory::title()       const { return i18nc("@title:window", "Decoding Table"); }
QString PodDecoderToolViewFactory::id()       const { return QStringLiteral("org.kde.okteta.PodDecoderToolView"); }
SidePosition PodDecoderToolViewFactory::defaultPosition() const { return RightSidePosition; }

AbstractToolView* PodDecoderToolViewFactory::create(AbstractTool* tool) const
{
    return new PODDecoderToolView(qobject_cast<PODDecoderTool*>(tool));
}

}
